<?php
	/*=======================================================================
	 * copyright (c) AL-Design Works 
	 * http://cms.al-design.jp/
	 * このソースファイルは CMS Designer の一部です。
	 * 詳しいライセンス規約についてはウェブサイトを参照してください。
	 *=======================================================================
	 */

	/* -----------------------------------------------------------------
	 * CMS Designerの内部文字エンコーディング。UTF-8固定以外は非推奨。
	 */
	$gCMSDEnableConvertingEncoding = false;		// CMSDの内部文字エンコーディングがUTF-8以外の時にtrueに設定。
	$gCMSDInternalEncoding = 'UTF-8';	// HTML等一般的な指定値　例：'EUC-JP'
	$gCMSDInternalEncodingPHP = 'UTF-8';	// PHP固有の指定値　例：'EUC-JPwin'

	function gCMSDEnableConvertingEncoding() { 
		global $gCMSDEnableConvertingEncoding;
		return $gCMSDEnableConvertingEncoding; 
	}
	
	function gCMSDInternalEncoding() { 
		global $gCMSDInternalEncoding;
		return $gCMSDInternalEncoding; 
	}
	
	function gCMSDInternalEncodingPHP() { 
		global $gCMSDInternalEncodingPHP;
		return $gCMSDInternalEncodingPHP; 
	}

	/* -----------------------------------------------------------------
	 * 画像の拡大・縮小時のパレットリサンプリングの有無。
	 * ※GDライブラリのバージョンによっては"1"が有効にならない場合があります。
	 * 0 : リサンプリングしない（動作が多少速くなる）
	 * 1 : リサンプリングする（滑らかになる）
	 */
	$gGDimagecopyfunc = 1;
	
	/* -----------------------------------------------------------------
	 * JPEG画像の拡大・縮小時の画質指定。0～100を指定します。100が最高画質です。
	 * 初期値 = 75;
	 */
	$gGDJpegQuality = 75;


	/* -----------------------------------------------------------------
	 *
	 *
	 *
	 */
	class ADImage
	{
		var $image = null;
		var $width = 0;
		var $height = 0;
		
		var $errorMessage = '';
	
		function __construct()
		{
			// 特になし
		}
		
		function loadFromFile( $filepath )
		{
			if ( ! file_exists( $filepath ) )
			{
				$this->errorMessage = $filepath . 'は存在しません。';
				return null;
			}
			
			// ソース画像の大きさを取得
			$info = getimagesize( $filepath );
			$width = $info[0];
			$height = $info[1];
			
			// ソース画像を取得
			switch( $info[2] )
			{
				case IMAGETYPE_GIF: // GIF
					$this->image = imagecreatefromgif( $filepath );
					break;
				
				case IMAGETYPE_JPEG: // JPEG
					$this->image = imagecreatefromjpeg( $filepath );
					break;
				
				case IMAGETYPE_PNG: // PNG
					$this->image = imagecreatefrompng( $filepath );
					break;
				
				default:
					$this->errorMessage = $filepath . 'は画像ファイルではありません。';
					return null;
			}
			
			if ( $width == 0 )
			{
				$width = imagesx( $this->image );
			}
			
			if ( $height == 0 )
			{
				$height = imagesy( $this->image );
			}
			
			$this->width = $width;
			$this->height = $height;
			
			return $this->image;
		
		}
		
		function loadFromResourceID( $image )
		{
			$this->image = $image;
			
			$this->width = imagesx( $image );
			$this->height = imagesy( $image );
		}
		
		function getWidth()
		{
			return $this->width;
		}
		
		function getHeight()
		{
			return $this->height;
		}
		
		function destroy()
		{
			imagedestroy($this->image);
			$this->image = null;
		}
		
		function saveToFile( $filepath, $imageType )
		{
			// 画像を指定したファイルに出力
			global $gGDJpegQuality;
			switch( $imageType )
			{
				case IMAGETYPE_GIF: // GIF
					imagegif( $this->image, $filepath );
					break;
				
				case IMAGETYPE_JPEG: // JPEG
					imagejpeg( $this->image, $filepath, $gGDJpegQuality );
					break;
				
				case IMAGETYPE_PNG: // PNG
					imagepng( $this->image, $filepath );
					break;
			}
		}
		
		
		/* ---------------------------------------------------------------------------
		 * イメージのリサイズ（縦横比固定）
		 * 指定したサイズにピッタリ収まるように縮小、又は拡大する。
		 * 
		 * return : ADImage
		 */
		function createResizedImage( $width = 0, $height = 0 )
		{
			$widthNew = $this->width;
			$heightNew = $this->height;
		
			// 指定された幅、又は高さに合わせた新しいサイズを計算
			/// 高さと幅を同時に指定されていたら、縮小率が高い方（値が小さい方）を優先する（領域内に収まるようにする）
			if ( $width != 0 and $height != 0 )
			{
				//if ( ( $width / $this->width ) >= ( $height / $this->height ) )	// 両辺に($this->width * $this->height)をかければ下の式と同じ意味になる。
				if ( ( $width * $this->height ) >= ( $height * $this->width ) )
				{
					$width = 0;
				}
				else
				{
					$height = 0;
				}
			}
			
			/// 縮小後のサイズを決定
			if ( $width != 0 )	// widthが指定されていたら
			{
				$widthNew = $width;
				$heightNew = ($width * $this->height) / $this->width;
			}
			else
			{
				$heightNew = $height;
				$widthNew = ($height * $this->width) / $this->height;
			}
			
			// 出力画像を生成
			$imageNew = null;
			if ( function_exists( 'imagecreatetruecolor' ) )
			{
				$imageNew = imagecreatetruecolor( $widthNew, $heightNew );
			}
			else
			{
				$imageNew = imagecreate( $widthNew, $heightNew );
			}
			
			// 出力画像に、ソース画像を縮小して描画
			global $gGDimagecopyfunc;
			if ( $gGDimagecopyfunc === 1 and function_exists( 'imagecopyresampled' ) )
			{
				imagecopyresampled( $imageNew, $this->image, 0, 0, 0, 0, $widthNew, $heightNew, $this->width, $this->height );
			}
			else
			{
				imagecopyresized( $imageNew, $this->image, 0, 0, 0, 0, $widthNew, $heightNew, $this->width, $this->height );
			}
			
			// ADImageの生成
			$adimageNew = new ADImage();
			$adimageNew->loadFromResourceID( $imageNew );
			
			return $adimageNew;
		
		}
	}


?>