<?php
	/*=======================================================================
	 * copyright (c) AL-Design Works 
	 * http://cms.al-design.jp/
	 * このソースファイルは CMS Designer の一部です。
	 * 詳しいライセンス規約についてはウェブサイトを参照してください。
	 *=======================================================================
	 */

	//require_once( dirname(__FILE__) . "/app.php.inc" );
	require_once( dirname(__FILE__) . "/manager.util.php.inc" );
	
	require_once( dirname(__FILE__) . "/manager.base.php.inc" );

	/* --------------------------------------------------------------------
	 * 整数入力項目クラス。
	 * 
	 */ 
	class GeoLocationEntryItem extends BaseEntryItem
	{
		
		/* ----------------------------------------------------------------
		 * コンストラクタ。
		 * $xmlSchemaData : 対応するスキーマDataのXML要素。
		 */
		function __construct( $xmlSchemaData, $entryName, $entryId	)
		{
			// ベースコンストラクタの呼び出し。
			parent::__construct( $xmlSchemaData, $entryName, $entryId  );
			
			/*
			$this->max = (int)( $xmlSchemaData->get_attribute('max') ); 
			$this->min = (int)( $xmlSchemaData->get_attribute('min') );
			*/
			
		}
		
		/* ----------------------------------------------------------------
		 * 当項目のXMLノードを新規作成する。
		 * $xmlDocParentEntry : エントリのDOMオブジェクト。
		 * $setInitData : 初期値。trueが指定されていた場合、スキーマで指定された値が設定される。デフォルト値はtrue。
		 * return : 新規XMLノード。
		 */
		function createNew( $xmlDocParentEntry, $setInitData = true )
		{
   			$newNode = parent::createNew( $xmlDocParentEntry, false ); // 現状、geolocation型には初期値を指定できない（指定しても無視される）。
			//$newNode->set_content( '' );
			
			$newNode->set_attribute( 'lat', '' );
			$newNode->set_attribute( 'lng', '' );
			$newNode->set_attribute( 'zoom', '' );
			
			return $newNode;
		}
		
		
		/* ----------------------------------------------------------------
		 * 入力内容でエントリ項目を更新する。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function update( $xpathEntry, $currentEntry )
		{
			// エントリXMLを取得。
			$xmlEntryDataList = $xpathEntry->xpath_eval( $currentEntry . '/' . $this->dataName );
			$xmlEntryData = $xmlEntryDataList->nodeset[0];
			
			
			// "name"属性に対応するPOSTが存在すれば、エントリに反映する。
			$lat = getPOSTParam( $this->dataName . '_LAT', '' );
			$lng = getPOSTParam( $this->dataName . '_LNG', '' );
			$zoom = getPOSTParam( $this->dataName . '_ZOOM' );
			
			// 必須チェック
			if ( ( $lat === '' or $lng === '' ) and ( $lat.$lng !== '' ) )	// latとlngどちらか一方だけが入力されていた場合
			{
				$this->errorMessage = sprintf("%s ：緯度と経度は両方入力する必要があります。", $this->dataCaption );
				return false;
			}
			
			if ( $lat.$lng === '' and $zoom !== '' )
			{
				$this->errorMessage = sprintf( "%s ：縮尺を入力するには緯度と経度も入力する必要があります。", $this->dataCaption );
				return false;
			}
			
			// 数値チェック
			if ( $lat !== '' and !is_numeric( $lat ) )
			{
				$this->errorMessage = sprintf( "%s ：緯度に数値以外が入力されました。", $this->dataCaption );
				return false;
			}
			
			if ( $lng !== '' and !is_numeric( $lng ) )
			{
				$this->errorMessage = sprintf( "%s ：経度に数値以外が入力されました。", $this->dataCaption );
				return false;
			}
			
			if ( $zoom !== '' and !is_numeric( $zoom ) )
			{
				$this->errorMessage = sprintf( "%s ：縮尺に数値以外が入力されました。", $this->dataCaption );
				return false;
			}
			
			$fLat = floatval( $lat );
			$fLng = floatval( $lng );
			$iZoom = intval( $zoom );
			
			// 範囲チェック
			if ( $lat !== '' and ( $fLat < -90 or $fLat > 90 ) )
			{
				$this->errorMessage = sprintf( "%s ：緯度が-90～+90の範囲を超えました。", $this->dataCaption );
				return false;
			}
			
			if ( $lng !== '' and ( $fLng < -180 or $fLng > 180 ) )
			{
				$this->errorMessage = sprintf( "%s ：経度が-180～+180の範囲を超えました。", $this->dataCaption );
				return false;
			}
			
			if ( $zoom !== '' and ( $iZoom < 0 or $iZoom > 19 ) )
			{
				$this->errorMessage = sprintf( "%s ：縮尺が0～19の範囲を超えました。", $this->dataCaption );
				return false;
			}
			
			
			// 保存する
			if ( $lat.$lng !== '' )	// 入力があったら
			{
				// まず、テキストノードを削除する（削除しないと、set_contentではテキストノードが増えるだけ）。
				EntryUtil::deleteTextNode( $xmlEntryData );
				
				// テキストノードに新しい値をsetする。
				$xmlEntryData->set_content( "($lat,$lng)" );
				
				$xmlEntryData->set_attribute( 'lat', $lat );
				$xmlEntryData->set_attribute( 'lng', $lng );
				$xmlEntryData->set_attribute( 'zoom', $zoom );
			}
			
			return true;
		
		}
		
		/* ----------------------------------------------------------------
		 * フォーム項目を描画するHTMLを返す。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function renderFormItem( $xpathEntry, $currentEntry )
		{
			// 現在使われていないメソッド。
		}
		

		/* ----------------------------------------------------------------
		 * フォーム項目を描画するHTMLを返す。
		 * $xpathEntry : エントリのXPathオブジェクト。
		 * $currentEntry : 現在のエントリ位置を表すXPath文字列。
		 */
		function renderFormItemXML( $xpathEntry, $currentEntry, &$xmlOutputEntryData )
		{
			$xmlEntryDataArray = $xpathEntry->xpath_eval( $currentEntry . '/' . $this->dataName );
			$xmlEntryData = $xmlEntryDataArray->nodeset[0];
			
			$lat = $xmlEntryData->get_attribute( 'lat' );
			$lng = $xmlEntryData->get_attribute( 'lng' );
			$zoom = $xmlEntryData->get_attribute( 'zoom' );
			
			// リクエストに値があれば、その値を再表示する（エラー時に前回入力値が保証されるようにする）
			$lat = getPOSTParam( $this->dataName . '_LAT', $lat );
			$lng = getPOSTParam( $this->dataName . '_LNG', $lng );
			$zoom = getPOSTParam( $this->dataName . '_ZOOM', $zoom );
			
			// データ出力
			$xmlOutputEntryData->set_attribute('lat', $lat );
			$xmlOutputEntryData->set_attribute('lng', $lng );
			$xmlOutputEntryData->set_attribute('zoom', $zoom );
		}
		
	}

?>